==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/CellRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellRangeDescription } from "./CellRangeDescription";
/**
 * @hidden
 */
export let CellRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class CellRangeDescriptionMetadata extends Base {
        static b(a) {
            if (CellRangeDescriptionMetadata.a == null) {
                CellRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CellRangeDescriptionMetadata.c(CellRangeDescriptionMetadata.a);
            }
            if (a.k(CellRangeDescriptionMetadata.a)) {
                return;
            }
            a.ab(CellRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("StartColumn", "Number:int");
            a.item("EndColumn", "Number:int");
            a.item("StartRow", "Number:int");
            a.item("EndRow", "Number:int");
        }
        static d(a) {
            CellRangeDescriptionMetadata.b(a);
            a.ad("CellRange", () => new CellRangeDescription());
            a.ac("CellRange", CellRangeDescriptionMetadata.a);
        }
    }
    CellRangeDescriptionMetadata.$t = /*@__PURE__*/ markType(CellRangeDescriptionMetadata, 'CellRangeDescriptionMetadata');
    CellRangeDescriptionMetadata.a = null;
    return CellRangeDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/CellRangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellRangeDescription } from "./CellRangeDescription";
/**
 * @hidden
 */
export let CellRangeDescriptionMetadata = /*@__PURE__*/ (() => {
    class CellRangeDescriptionMetadata extends Base {
        static b(a) {
            if (CellRangeDescriptionMetadata.a == null) {
                CellRangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CellRangeDescriptionMetadata.c(CellRangeDescriptionMetadata.a);
            }
            if (a.k(CellRangeDescriptionMetadata.a)) {
                return;
            }
            a.ac(CellRangeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("StartColumn", "Number:int");
            a.item("EndColumn", "Number:int");
            a.item("StartRow", "Number:int");
            a.item("EndRow", "Number:int");
        }
        static d(a) {
            CellRangeDescriptionMetadata.b(a);
            a.ae("CellRange", () => new CellRangeDescription());
            a.ad("CellRange", CellRangeDescriptionMetadata.a);
        }
    }
    CellRangeDescriptionMetadata.$t = /*@__PURE__*/ markType(CellRangeDescriptionMetadata, 'CellRangeDescriptionMetadata');
    CellRangeDescriptionMetadata.a = null;
    return CellRangeDescriptionMetadata;
})();
